Implements a common server for Planetary microservices.
Structs
- Error
- Represents a generic error from the server.
- Json
- An extractor that wraps the JSON extractor of Axum.
- Path
- An extractor that wraps the path extractor of Axum.
- Query
- An extractor that wraps the query extractor of Axum (extra).
- Server
- The state for a task execution service (TES) server.
- Server
Builder - Use builder syntax to set the inputs and finish with
build().
Constants
- DEFAULT_
ADDRESS - The default address to bind the server to.
- DEFAULT_
PORT - The default port to bind the server to.
Type Aliases
- Server
Response - Represents the response type for most endpoints.